@@ -12,7 +12,7 @@ from redshift_client.table.core import (
 
 @dataclass(frozen=True)
 class SchemaId:
-    _name: str
+    name: str
 
 
 @dataclass(frozen=True)
