@@ -18,26 +18,37 @@ from redshift_client.table.core import (
 )
 
 
+@dataclass(frozen=True)
+class ManifestId:
+    uri: str
+
+
 @dataclass(frozen=True)
 class TableClient:
     _db_client: SqlClient
 
-    def unload(self, table: TableId, bucket: str, role: str) -> Cmd[None]:
+    def unload(
+        self, table: TableId, prefix: str, role: str
+    ) -> Cmd[ManifestId]:
+        """
+        prefix: a s3 uri prefix
+        role: an aws role id-arn
+        """
         stm = (
             "UNLOAD ('SELECT * FROM {schema}.{table}')"
-            "TO %(bucket)s iam_role %(role)s MANIFEST"
+            "TO %(prefix)s iam_role %(role)s MANIFEST"
         )
         return self._db_client.execute(
             dynamic_query(
                 stm,
-                FrozenDict(
-                    {"schema": table._schema._name, "table": table._name}
-                ),
+                FrozenDict({"schema": table.schema.name, "table": table.name}),
             ),
-            FrozenDict({"bucket": bucket, "role": role}),
-        )
+            FrozenDict({"prefix": prefix, "role": role}),
+        ).map(lambda _: ManifestId(f"{prefix}manifest"))
 
-    def load(self, table: TableId, manifest: str, role: str) -> Cmd[None]:
+    def load(
+        self, table: TableId, manifest: ManifestId, role: str
+    ) -> Cmd[None]:
         stm = (
             "COPY {schema}.{table} FROM %(manifest_file)s"
             "iam_role %(role)s MANIFEST"
@@ -45,9 +56,7 @@ class TableClient:
         return self._db_client.execute(
             dynamic_query(
                 stm,
-                FrozenDict(
-                    {"schema": table._schema._name, "table": table._name}
-                ),
+                FrozenDict({"schema": table.schema.name, "table": table.name}),
             ),
-            FrozenDict({"manifest_file": manifest, "role": role}),
+            FrozenDict({"manifest_file": manifest.uri, "role": role}),
         )
