@@ -23,8 +23,8 @@ from typing import (
 
 @dataclass(frozen=True)
 class TableId:
-    _schema: SchemaId
-    _name: str
+    schema: SchemaId
+    name: str
 
 
 @dataclass(frozen=True)
